[jbpm-commits] JBoss JBPM SVN: r4317 - jbpm4/trunk/modules/examples/src/test/java/org/jbpm/examples/task/candidates.

do-not-reply at jboss.org do-not-reply at jboss.org
Tue Mar 24 10:59:12 EDT 2009


Author: heiko.braun at jboss.com
Date: 2009-03-24 10:59:12 -0400 (Tue, 24 Mar 2009)
New Revision: 4317

Modified:
   jbpm4/trunk/modules/examples/src/test/java/org/jbpm/examples/task/candidates/TaskCandidatesTest.java
Log:
Fix TaskCandidatesTest: dedicate test group 'sales-test-group' to avoid clash with the default indentities

Modified: jbpm4/trunk/modules/examples/src/test/java/org/jbpm/examples/task/candidates/TaskCandidatesTest.java
===================================================================
--- jbpm4/trunk/modules/examples/src/test/java/org/jbpm/examples/task/candidates/TaskCandidatesTest.java	2009-03-24 14:53:08 UTC (rev 4316)
+++ jbpm4/trunk/modules/examples/src/test/java/org/jbpm/examples/task/candidates/TaskCandidatesTest.java	2009-03-24 14:59:12 UTC (rev 4317)
@@ -34,8 +34,8 @@
 public class TaskCandidatesTest extends JbpmTestCase {
 
   public void testGroupCandidateAssignment() {
-    // create johndoe and joesmoe as members of the sales group
-    String salesGroupId = identityService.createGroup("sales");
+    // create johndoe and joesmoe as members of the sales-test-group group
+    String salesGroupId = identityService.createGroup("sales-test-group");
 
     identityService.createUser("johndoe", "johndoe", "John", "Doe");
     identityService.createMembership("johndoe", salesGroupId);
@@ -50,12 +50,12 @@
     String executionId = execution.getId();
     
     List<Task> taskList = taskService.getGroupTaskList("johndoe", 0, 10);
-    assertEquals(1, taskList.size());
+    assertEquals("Expected a single task being created", 1, taskList.size());
     Task task = taskList.get(0);
     assertEquals("review", task.getName());
 
     taskList = taskService.getGroupTaskList("joesmoe", 0, 10);
-    assertEquals(1, taskList.size());
+    assertEquals("Expected a single task being created", 1, taskList.size());
     task = taskList.get(0);
     assertEquals("review", task.getName());
 
@@ -65,9 +65,9 @@
     
     // verify that the group task lists are now empty
     taskList = taskService.getGroupTaskList("johndoe", 0, 10);
-    assertEquals(0, taskList.size());
+    assertEquals("Expected a no task to remain", 0, taskList.size());
     taskList = taskService.getGroupTaskList("joesmoe", 0, 10);
-    assertEquals(0, taskList.size());
+    assertEquals("Expected a no task to remain",0, taskList.size());
 
     // verify that the task now shows up in the personal task list for johndoe
     taskList = taskService.getPersonalTaskList("johndoe", 0, 10);




More information about the jbpm-commits mailing list